**# op_mewtwo**

This package contains a python class called Risk Dataframe which contains methods to perform a missing not at random analysis and to automate a risk-based segmentation process by analyzing all the features in the dataset and identifying the best split for segmenting each feature. 

In order to effectively use the methods in this class, some degree of data cleaning and preparation will be required. A demo file using a Car Loans Portfolio Dataset is provided.


To access the Risk Dataframe class within the Mewtwo package, please do the following,

**from op_mewtwo.RiskDataframe import RiskDataframe**

